==> haskell-hslua-module-version-1.1.1-115-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-HE4lRshviVvEqIAJG8ArV2
key:                  hslua-module-version-1.1.1-HE4lRshviVvEqIAJG8ArV2
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  28b7648ac0aa082ec9c656c0cb66f7f6
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-HE4lRshviVvEqIAJG8ArV2
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.2-AoHPEgJI7FU53jBqBLyzwJ
    hslua-marshalling-2.3.1-ioF10Y7zsM1Vkhsp51ow4
    hslua-packaging-2.3.1-58eSZDB6wun15nTrPiPJrX text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-version-1.1.1-134-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-version.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-version
version:              1.1.1
visibility:           public
id:                   hslua-module-version-1.1.1-Js4f9RjpwAq6NTCo85H7Qi
key:                  hslua-module-version-1.1.1-Js4f9RjpwAq6NTCo85H7Qi
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with version specifiers.
description:          Wrapper for the Data.Version.Version Haskell type.
category:             Foreign
abi:                  baf630b61ffa67e2ba72f60e7f414608
exposed:              True
exposed-modules:      HsLua.Module.Version
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-version-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-version
hs-libraries:         HShslua-module-version-1.1.1-Js4f9RjpwAq6NTCo85H7Qi
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.2-JQMgiBnrP8U52dzk17lMrQ
    hslua-marshalling-2.3.1-1gCbRdTXAK0FajTP4EoWq5
    hslua-packaging-2.3.1-43quJ4tUGXt3u0qKn5mWql text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-version/html/hslua-module-version.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-version/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
